@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -11,8 +11,11 @@
  *          If null, there will be no referrer header and no security check.
  * @param postData Form POST data, or null.
  * @param event The triggering event (for the purpose of determining whether to open in the background), or null
+ * @param allowThirdPartyFixup if true, then we allow the URL text to be sent to third party
+ * services (e.g., Google's I Feel Lucky) for interpretation. This parameter may be undefined in
+ * which case it is treated as false.
  */ 
-function openNewTabWith(href, sourceURL, postData, event)
+function openNewTabWith(href, sourceURL, postData, event, allowThirdPartyFixup)
 {
   if (sourceURL)
     urlSecurityCheck(href, sourceURL);
@@ -44,10 +47,11 @@ function openNewTabWith(href, sourceURL, postData, event)
 
   var referrerURI = sourceURL ? makeURI(sourceURL) : null;
 
-  browser.loadOneTab(href, referrerURI, originCharset, postData, loadInBackground);
+  browser.loadOneTab(href, referrerURI, originCharset, postData, loadInBackground,
+                     allowThirdPartyFixup || false);
 }
 
-function openNewWindowWith(href, sourceURL, postData)
+function openNewWindowWith(href, sourceURL, postData, allowThirdPartyFixup)
 {
   if (sourceURL)
     urlSecurityCheck(href, sourceURL);
@@ -62,37 +66,40 @@ function openNewWindowWith(href, sourceURL, postData)
 
   var referrerURI = sourceURL ? makeURI(sourceURL) : null;
 
-  window.openDialog(getBrowserURL(), "_blank", "chrome,all,dialog=no", href, charsetArg, referrerURI, postData);
+  window.openDialog(getBrowserURL(), "_blank", "chrome,all,dialog=no",
+                    href, charsetArg, referrerURI, postData, allowThirdPartyFixup);
 }
 
 /**
- * urlSecurityCheck: JavaScript wrapper for CheckLoadURI.
+ * urlSecurityCheck: JavaScript wrapper for CheckLoadURIStr.
  * If |sourceURL| is not allowed to link to |url|, this function throws with an error message.
  *
  * @param url The URL a page has linked to.
  * @param sourceURL The URL of the document from which the URL came.
+ * @param flags Flags to be passed to checkLoadURIStr. If undefined,
+ *              nsIScriptSecurityManager.STANDARD will be passed to checkLoadURIStr.
  */
-function urlSecurityCheck(url, sourceURL)
+function urlSecurityCheck(url, sourceURL, flags)
 {
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
+  if (flags === undefined)
+    flags = nsIScriptSecurityManager.STANDARD;
+
   try {
-    secMan.checkLoadURIStr(sourceURL, url, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(sourceURL, url, flags);
   } catch (e) {
     throw "Load of " + url + " from " + sourceURL + " denied.";
   }
 }
 
 function webPanelSecurityCheck(aSourceURL, aDestURL) {
-  var sourceURI = makeURI(aSourceURL);
-  var destURI = makeURI(aDestURL);
-
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
   try {
-    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(aSourceURL, aDestURL, nsIScriptSecurityManager.STANDARD);
   } catch (e) {
     return false;
   }
@@ -246,8 +253,8 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
       charset = aDocument.characterSet;
     else if (aReferrer)
       charset = aReferrer.originCharset;
-    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition,
-                 charset);
+    initFileInfo(fileInfo, aURL, charset, aDocument,
+                 aContentType, aContentDisposition);
     var fpParams = {
       fpTitleKey: aFilePickerTitleKey,
       isDocument: isDocument,
@@ -387,18 +394,16 @@ function FileInfo(aSuggestedFileName, aFileName, aFileBaseName, aFileExt, aUri)
  * for confirmation in the file picker dialog.
  * @param aFI A FileInfo structure into which we'll put the results of this method.
  * @param aURL The String representation of the URL of the document being saved
+ * @param aURLCharset The charset of aURL.
  * @param aDocument The document to be saved
  * @param aContentType The content type we're saving, if it could be
  *        determined by the caller.
  * @param aContentDisposition The content-disposition header for the object
  *        we're saving, if it could be determined by the caller.
- * @param aURLCharset The charset of aURL.
  */
-function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition,
-                      aURLCharset)
+function initFileInfo(aFI, aURL, aURLCharset, aDocument,
+                      aContentType, aContentDisposition)
 {
-  if (!aURLCharset && aDocument && aDocument.characterSet)
-    aURLCharset = aDocument.characterSet;
   try {
     // Get an nsIURI object from aURL if possible:
     try {
@@ -457,9 +462,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 504 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 509 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 507 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 512 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -847,7 +852,10 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 898 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 903 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/content/contentAreaUtils.js"
+
+  // Remove leading dots
+  aFile = aFile.replace(/^\.+/, "");
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
