@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/content/nsDragAndDrop.js"
+//@line 39 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/content/nsDragAndDrop.js"
 
 /** 
  *  nsTransferable - a wrapper for nsITransferable that simplifies
@@ -397,7 +397,7 @@ var nsDragAndDrop = {
         // cancel the drag. even if it's not, there's not much
         // we can do, so be silent.
       }
-      aEvent.preventBubble();
+      aEvent.stopPropagation();
     },
 
   /** 
@@ -425,7 +425,7 @@ var nsDragAndDrop = {
               aDragDropObserver.onDragOver(aEvent, 
                                            flavourSet.flavourTable[flavour], 
                                            this.mDragSession);
-              aEvent.preventBubble();
+              aEvent.stopPropagation();
               break;
             }
         }
@@ -458,7 +458,7 @@ var nsDragAndDrop = {
         var dropData = multiple ? transferData : transferData.first.first;
         aDragDropObserver.onDrop(aEvent, dropData, this.mDragSession);
       }
-      aEvent.preventBubble();
+      aEvent.stopPropagation();
     },
 
   /** 
