@@ -1,6 +1,6 @@
-//@line 40 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 40 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 
-//@line 42 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 42 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 var helpBrowser;
 var helpSearchPanel;
 var emptySearch;
@@ -12,16 +12,16 @@ var helpGlossaryPanel;
 var strBundle;
 var gTocDSList = "";
 
-//@line 54 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 54 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 const NC = "http://home.netscape.com/NC-rdf#";
 const MAX_LEVEL = 40; // maximum depth of recursion in search datasources.
 const MAX_HISTORY_MENU_ITEMS = 6;
 
-//@line 68 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 68 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 const platform = "unix";
-//@line 72 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 72 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 
-//@line 74 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 74 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 const RDF = Components.classes["@mozilla.org/rdf/rdf-service;1"]
     .getService(Components.interfaces.nsIRDFService);
 const RDF_ROOT = RDF.GetResource("urn:root");
@@ -48,13 +48,9 @@ var RE;
 
 var helpFileURI;
 var helpFileDS;
-//@line 102 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 102 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 var helpBaseURI;
 
-var gIgnoreFocus = false;
-var gClickSelectsAll;
-var gIgnoreClick = false;
-
 /* defaultTopic is either set
    1. in the openHelp() call, passed as an argument to the Help window and
       evaluated in init(), or
@@ -66,7 +62,7 @@ var defaultTopic;
 
 const NSRESULT_RDF_SYNTAX_ERROR = 0x804e03f7;
 
-//@line 123 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 119 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function displayTopic(topic) {
     // Get the page to open.
     var uri = getLink(topic);
@@ -79,7 +75,7 @@ function displayTopic(topic) {
       loadURI(uri);
 }
 
-//@line 136 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 132 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function init() {
   // Cache panel references.
   helpSearchPanel = document.getElementById("help-search-panel");
@@ -91,7 +87,7 @@ function init() {
   strBundle = document.getElementById("bundle_help");
   emptySearchText = strBundle.getString("emptySearchText");
 
-  initFindBar();
+  gFindBar.initFindBar();
 
   // Get the content pack, base URL, and help topic
   var helpTopic = defaultTopic;
@@ -126,8 +122,9 @@ function init() {
 
   webProgress.addProgressListener(window.XULBrowserWindow, Components.interfaces.nsIWebProgress.NOTIFY_ALL);
 
-  gClickSelectsAll = getBoolPref("browser.urlbar.clickSelectsAll", true);
-  
+  var searchBox = document.getElementById("findText");
+  searchBox.clickSelectsAll = getBoolPref("browser.urlbar.clickSelectsAll", true);
+
   setTimeout(focusSearch, 0);
 }
 
@@ -159,7 +156,7 @@ function hideSearchSidebar(aEvent) {
   tableOfContents.removeAttribute("hidden");
 }
 
-//@line 219 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 216 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function loadHelpRDF() {
   if (!helpFileDS) {
     try {
@@ -234,12 +231,12 @@ function loadHelpRDF() {
   }
 }
 
-//@line 295 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 292 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function filterDatasourceByPlatform(aDatasource) {
   filterNodeByPlatform(aDatasource, RDF_ROOT, 0);
 }
 
-//@line 301 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 298 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function filterNodeByPlatform(aDatasource, aCurrentResource, aCurrentLevel) {
   if (aCurrentLevel > MAX_LEVEL) {
      log("Datasources over " + MAX_LEVEL + " levels deep are unsupported.");
@@ -256,7 +253,7 @@ function filterNodeByPlatform(aDatasource, aCurrentResource, aCurrentLevel) {
   }
 }
 
-//@line 320 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 317 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function filterSeqByPlatform(aDatasource, aNode, aCurrentLevel) {
   // get nc:subheading children into an enumerator
   var RDFC = Components.classes["@mozilla.org/rdf/container;1"]
@@ -289,7 +286,7 @@ function filterSeqByPlatform(aDatasource, aNode, aCurrentLevel) {
   }
 }
 
-//@line 354 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 351 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function normalizeLinks(helpBaseURI, links) {
   if (!helpBaseURI) {
     return links;
@@ -331,7 +328,7 @@ function getLink(ID) {
     return null;
 }
 
-//@line 397 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 394 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function getHelpFileURI() {
     return helpFileURI;
 }
@@ -366,33 +363,6 @@ function goBack() {
   }
 }
 
-/* copied from browser.js */
-function BrowserReloadWithFlags(reloadFlags) {
-    /* First, we'll try to use the session history object to reload so 
-     * that framesets are handled properly. If we're in a special 
-     * window (such as view-source) that has no session history, fall 
-     * back on using the web navigation's reload method.
-     */
-
-    var webNav = getWebNavigation();
-    try {
-      var sh = webNav.sessionHistory;
-      if (sh)
-        webNav = sh.QueryInterface(Components.interfaces.nsIWebNavigation);
-    } catch (e) {
-    }
-
-    try {
-      webNav.reload(reloadFlags);
-    } catch (e) {
-    }
-}
-
-function reload() {
-  const reloadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
-  return BrowserReloadWithFlags(reloadFlags);
-}
-
 function goForward() {
     try
     {
@@ -570,39 +540,12 @@ function onselect_loadURI(tree) {
     }// when switching between tabs a spurious row number is returned.
 }
 
-// copied from browser.js to handle the searchbar
-function SearchbarFocusHandler(aEvent, aElt)
-{
-  if (gIgnoreFocus)
-    gIgnoreFocus = false;
-  else if (gClickSelectsAll)
-    aElt.select();
-}
-
-function SearchbarMouseDownHandler(aEvent, aElt)
-{
-  if (aElt.hasAttribute("focused")) {
-    gIgnoreClick = true;
-  } else {
-    gIgnoreFocus = true;
-    gIgnoreClick = false;
-    aElt.setSelectionRange(0, 0);
-  }
-}
-
-function SearchbarClickHandler(aEvent, aElt)
-{
-  if (!gIgnoreClick && gClickSelectsAll && aElt.selectionStart == aElt.selectionEnd)
-    aElt.select();
-}
-
-
 function focusSearch() {
   var searchBox = document.getElementById("findText");
   searchBox.focus();
 }
 
-//@line 669 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 612 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function doFind() {
     if (document.getElementById("help-search-sidebar").hidden)
       showSearchSidebar();
@@ -752,7 +695,7 @@ function getLiteralValue(literal, defaultValue) {
     return null;
 }
 
-//@line 819 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 762 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function log(aText) {
     CONSOLE_SERVICE.logStringMessage(aText);
 }
@@ -769,7 +712,7 @@ function getBoolPref (aPrefname, aDefault)
   }
 }
 
-//@line 836 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/components/help/content/help.js"
+//@line 779 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/components/help/content/help.js"
 function getXulWin()
 {
   window.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
