@@ -1,4 +1,4 @@
-//@line 42 "/usr/obj/i386/xulrunner-1.8.0.4/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 42 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/mozapps/downloads/content/downloads.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -718,20 +718,6 @@ var gDownloadViewController = {
   }
 };
 
-function onDownloadShowOptions()
-{
-  var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService();
-  var windowManagerInterface = windowManager.QueryInterface(Components.interfaces.nsIWindowMediator);
-  var topWindow = windowManagerInterface.getMostRecentWindow("Browser:Options");
-  if (topWindow) {
-    topWindow.focus();
-    topWindow.switchPage("catDownloadsButton");
-  }
-  else
-    openDialog("chrome://browser/content/pref/pref.xul", "PrefWindow",
-              "chrome,titlebar,resizable,modal", "catDownloadsButton");
-}
-
 function onDownloadShowInfo()
 {
   if (gDownloadsView.selectedItem)
@@ -752,8 +738,15 @@ function initAutoDownloadDisplay()
 
     function getSpecialFolderKey(aFolderType) 
     {
-//@line 807 "/usr/obj/i386/xulrunner-1.8.0.4/mozilla/toolkit/mozapps/downloads/content/downloads.js"
-      return "Home";
+    if (aFolderType == "Desktop")
+      return "Desk";
+
+    if (aFolderType != "Downloads")
+      throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
+
+//@line 793 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+    return "Home";
+//@line 796 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/mozapps/downloads/content/downloads.js"
     }
     
     function getDownloadsFolder(aFolder)
