@@ -1,41 +1,24 @@
-//@line 37 "/usr/obj/ports/xulrunner-1.8.0.4/mozilla/toolkit/mozapps/extensions/content/update.js"
+//@line 38 "/usr/obj/ports/xulrunner-1.8.1.4/mozilla/toolkit/mozapps/extensions/content/update.js"
 
-//
-// This UI can be opened from the following places, and in the following modes:
-//
-// - from the Version Compatibility Checker at startup
-//    as the application starts a check is done to see if the application being
-//    started is the same version that was started last time. If it isn't, a
-//    list of UpdateItems that are incompatible with the verison being 
-//    started is generated and this UI opened with that list. This UI then
-//    offers to check for updates to those UpdateItems that are compatible
-//    with the version of the application being started. 
-//    
-//    In this mode, the wizard is opened to panel 'mismatch'. 
+// This UI is only opened from the Extension Manager when the app is upgraded.
 
 const nsIUpdateItem = Components.interfaces.nsIUpdateItem;
 const nsIAUCL = Components.interfaces.nsIAddonUpdateCheckListener;
 
 const PREF_UPDATE_EXTENSIONS_ENABLED            = "extensions.update.enabled";
-const PREF_UPDATE_EXTENSIONS_AUTOUPDATEENABLED  = "extensions.update.autoUpdateEnabled";
-
-var gShowMismatch = null;
-var gUpdateTypes  = null;
+const PREF_XPINSTALL_ENABLED                    = "xpinstall.enabled";
 
 var gUpdateWizard = {
-  // The items to check for updates for (e.g. an extension, some subset of extensions, 
-  // all extensions, a list of compatible extensions, etc...)
+  // When synchronizing app compatibility info this contains all installed
+  // add-ons. When checking for compatible versions this contains only
+  // incompatible add-ons.
   items: [],
   // The items that we found updates available for
   itemsToUpdate: [],
-  // The items that we successfully installed updates for
-  updatedCount: 0,
   shouldSuggestAutoChecking: false,
   shouldAutoCheck: false,
-  
-  remainingExtensionUpdateCount: 0,
-  
-  succeeded: true,
+  xpinstallEnabled: false,
+  xpinstallLocked: false,
   
   init: function ()
   {
@@ -46,12 +29,28 @@ var gUpdateWizard = {
     var pref = 
         Components.classes["@mozilla.org/preferences-service;1"].
         getService(Components.interfaces.nsIPrefBranch);
-    this.shouldSuggestAutoChecking = 
-      gShowMismatch && 
-      !pref.getBoolPref(PREF_UPDATE_EXTENSIONS_AUTOUPDATEENABLED);
 
-    document.documentElement.currentPage = 
-      document.getElementById("versioninfo");
+    try {
+      this.shouldSuggestAutoChecking = 
+        !pref.getBoolPref(PREF_UPDATE_EXTENSIONS_ENABLED);
+    }
+    catch (e) {
+    }
+
+    try {
+      this.xpinstallEnabled = pref.getBoolPref(PREF_XPINSTALL_ENABLED);
+      this.xpinstallLocked = pref.prefIsLocked(PREF_XPINSTALL_ENABLED);
+    }
+    catch (e) {
+    }
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    if (ioService.offline)
+      document.documentElement.currentPage = 
+        document.getElementById("offline");
+    else
+      document.documentElement.currentPage = 
+        document.getElementById("versioninfo");
   },
   
   onWizardFinish: function ()
@@ -59,7 +58,7 @@ var gUpdateWizard = {
     var pref = Components.classes["@mozilla.org/preferences-service;1"]
                          .getService(Components.interfaces.nsIPrefBranch);
     if (this.shouldSuggestAutoChecking)
-      pref.setBoolPref(PREF_UPDATE_EXTENSIONS_ENABLED, this.shouldAutoCheck); 
+      pref.setBoolPref(PREF_UPDATE_EXTENSIONS_ENABLED, this.shouldAutoCheck);
   },
   
   _setUpButton: function (aButtonID, aButtonKey, aDisabled)
@@ -69,7 +68,7 @@ var gUpdateWizard = {
     if (aButtonKey) {
       button.label = strings.getString(aButtonKey);
       try {
-        button.accesskey = strings.getString(aButtonKey + "Accesskey");
+        button.setAttribute("accesskey", strings.getString(aButtonKey + "Accesskey"));
       }
       catch (e) {
       }
@@ -95,18 +94,20 @@ var gUpdateWizard = {
                "modal", { state: aState, errors: aErrors });
   },
   
+  // Displays a list of items that had an error during the update check. We
+  // don't display the actual error that occured since
+  // nsIAddonUpdateCheckListener doesn't return the error details.
   showUpdateCheckErrors: function ()
   {
     var errors = [];
     for (var i = 0; i < this.errorItems.length; ++i)
-      errors.push({ name: this.errorItems[i].name, error: true, 
-                    item: this.errorItems[i] });
+      errors.push({ name: this.errorItems[i].name, error: true });
     this.showErrors("checking", errors);
   },
 
   checkForErrors: function (aElementIDToShow)
   {
-    if (this.errorOnGeneric || this.errorItems.length > 0)
+    if (this.errorItems.length > 0)
       document.getElementById(aElementIDToShow).hidden = false;
   },
   
@@ -122,6 +123,22 @@ var gUpdateWizard = {
   }
 };
 
+var gOfflinePage = {
+  onPageAdvanced: function ()
+  {
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    ioService.offline = false;
+    return true;
+  },
+  
+  toggleOffline: function ()
+  {
+    var nextbtn = document.documentElement.getButton("next");
+    nextbtn.disabled = !nextbtn.disabled;
+  }
+}
+
 var gVersionInfoPage = {
   _completeCount: 0,
   _totalCount: 0,
@@ -177,8 +194,17 @@ var gVersionInfoPage = {
         }
       }
     }
+    else if (status == nsIAUCL.STATUS_FAILURE)
+      gUpdateWizard.errorItems.push(addon);
+
     ++this._completeCount;
 
+    // Update the status text and progress bar
+    var updateStrings = document.getElementById("updateStrings");
+    var status = document.getElementById("versioninfo.status");
+    var statusString = updateStrings.getFormattedString("statusPrefix", [addon.name]);
+    status.setAttribute("value", statusString);
+
     // Update the status text and progress bar
     var progress = document.getElementById("versioninfo.progress");
     progress.mode = "normal";
@@ -214,9 +240,15 @@ var gMismatchPage = {
 };
 
 var gUpdatePage = {
+  _totalCount: 0,
   _completeCount: 0,
   onPageShow: function ()
   {
+    if (!gUpdateWizard.xpinstallEnabled && gUpdateWizard.xpinstallLocked) {
+      document.documentElement.currentPage = document.getElementById("adminDisabled");
+      return;
+    }
+
     gUpdateWizard.setButtonLabels(null, true, 
                                   "nextButtonText", true, 
                                   "cancelButtonText", false);
@@ -224,9 +256,10 @@ var gUpdatePage = {
 
     gUpdateWizard.errorItems = [];
     
+    this._totalCount = gUpdateWizard.items.length;
     var em = Components.classes["@mozilla.org/extensions/manager;1"]
                        .getService(Components.interfaces.nsIExtensionManager);
-    em.update(gUpdateWizard.items, gUpdateWizard.items.length, false, this);
+    em.update(gUpdateWizard.items, this._totalCount, false, this);
   },
 
   /////////////////////////////////////////////////////////////////////////////
@@ -247,7 +280,7 @@ var gUpdatePage = {
   onAddonUpdateEnded: function(addon, status) {
     if (status == nsIAUCL.STATUS_UPDATE)
       gUpdateWizard.itemsToUpdate.push(addon);
-    else if (status == nsIAUCL.STATE_ERROR)
+    else if (status == nsIAUCL.STATUS_FAILURE)
       gUpdateWizard.errorItems.push(addon);
       
     ++this._completeCount;
@@ -255,11 +288,11 @@ var gUpdatePage = {
     // Update the status text and progress bar
     var updateStrings = document.getElementById("updateStrings");
     var status = document.getElementById("checking.status");
-    var statusString = updateStrings.getFormattedString("checkingPrefix", [addon.name]);
+    var statusString = updateStrings.getFormattedString("statusPrefix", [addon.name]);
     status.setAttribute("value", statusString);
 
     var progress = document.getElementById("checking.progress");
-    progress.value = Math.ceil((this._completeCount / gUpdateWizard.items.length) * 100);
+    progress.value = Math.ceil((this._completeCount / this._totalCount) * 100);
   },
   
   /////////////////////////////////////////////////////////////////////////////
@@ -273,97 +306,75 @@ var gUpdatePage = {
 };
  
 var gFoundPage = {
-  _nonAppItems: [],
-  
-  _newestInfo: null,
-
-  buildAddons: function ()
-  {
-    var hasExtensions = false;
-    var foundAddonsList = document.getElementById("found.addons.list");
-    var uri = Components.classes["@mozilla.org/network/standard-url;1"]
-                        .createInstance(Components.interfaces.nsIURI);
-    var itemCount = gUpdateWizard.itemsToUpdate.length;
-    for (var i = 0; i < itemCount; ++i) {
-      var item = gUpdateWizard.itemsToUpdate[i];
-      var checkbox = document.createElement("checkbox");
-      foundAddonsList.appendChild(checkbox);
-      checkbox.setAttribute("type", "update");
-      checkbox.label        = item.name + " " + item.version;
-      checkbox.setAttribute("URL", item.xpiURL);
-      checkbox.setAttribute("hash", item.xpiHash);
-      checkbox.infoURL      = "";
-      checkbox.internalName = "";
-      uri.spec              = item.xpiURL;
-      checkbox.setAttribute("source", uri.host);
-      checkbox.checked      = true;
-      hasExtensions         = true;
-    }
-
-    if (hasExtensions) {
-      var addonsHeader = document.getElementById("addons");
-      var strings = document.getElementById("updateStrings");
-      addonsHeader.label = strings.getFormattedString("updateTypeExtensions", [itemCount]);
-      addonsHeader.collapsed = false;
-    }
-  },
-
-  _initialized: false,
   onPageShow: function ()
   {
     gUpdateWizard.setButtonLabels(null, true, 
                                   "installButtonText", false, 
                                   null, false);
-    document.documentElement.getButton("next").focus();
-    
-    var updates = document.getElementById("found.updates");
-    if (!this._initialized) {
-      this._initialized = true;
-      updates.computeSizes();
-      this.buildAddons();
+
+    var foundUpdates = document.getElementById("found.updates");
+    var itemCount = gUpdateWizard.itemsToUpdate.length;
+    for (var i = 0; i < itemCount; ++i) {
+      var item = gUpdateWizard.itemsToUpdate[i];
+      var listItem = foundUpdates.appendItem(item.name + " " + item.version,
+                                             item.xpiURL);
+      listItem.setAttribute("type", "checkbox");
+      listItem.setAttribute("checked", "true");
+      listItem.setAttribute("URL", item.xpiURL);
+      listItem.setAttribute("hash", item.xpiHash);
     }
-        
-    var kids = updates._getRadioChildren();
-    for (var i = 0; i < kids.length; ++i) {
-      if (kids[i].collapsed == false) {
-        updates.selectedIndex = i;
-        break;
-      }
+
+    if (!gUpdateWizard.xpinstallEnabled) {
+      document.getElementById("xpinstallDisabledAlert").hidden = false;
+      document.getElementById("enableXPInstall").focus();
+      document.documentElement.getButton("next").disabled = true;
+    }
+    else {
+      document.documentElement.getButton("next").focus();
+      document.documentElement.getButton("next").disabled = false;
     }
   },
     
-  onSelect: function (aEvent)
+  toggleXPInstallEnable: function(aEvent)
   {
-    var updates = document.getElementById("found.updates");
+    var enabled = aEvent.target.checked;
+    gUpdateWizard.xpinstallEnabled = enabled;
+    var pref = Components.classes["@mozilla.org/preferences-service;1"]
+                         .getService(Components.interfaces.nsIPrefBranch);
+    pref.setBoolPref(PREF_XPINSTALL_ENABLED, enabled);
+    this.updateNextButton();
+  },
+
+  updateNextButton: function ()
+  {
+    if (!gUpdateWizard.xpinstallEnabled) {
+      document.documentElement.getButton("next").disabled = true;
+      return;
+    }
+
     var oneChecked = false;
-    var items = updates.selectedItem.getElementsByTagName("checkbox");
-    for (var i = 0; i < items.length; ++i) {  
-      if (items[i].checked) {
-        oneChecked = true;
-        break;
-      }
+    var foundUpdates = document.getElementById("found.updates");
+    var updates = foundUpdates.getElementsByTagName("listitem");;
+    for (var i = 0; i < updates.length; ++i) {
+      if (!updates[i].checked)
+        continue;
+      oneChecked = true;
+      break;
     }
 
-    var strings = document.getElementById("updateStrings");
     gUpdateWizard.setButtonLabels(null, true, 
                                   "installButtonText", true, 
                                   null, false);
-    var text = strings.getString("foundInstructions");
     document.getElementById("found").setAttribute("next", "installing"); 
     document.documentElement.getButton("next").disabled = !oneChecked;
-
-    var foundInstructions = document.getElementById("foundInstructions");
-    while (foundInstructions.hasChildNodes())
-      foundInstructions.removeChild(foundInstructions.firstChild);
-    foundInstructions.appendChild(document.createTextNode(text));
   }
 };
 
 var gInstallingPage = {
   _installing       : false,
-  _restartRequired  : false,
   _objs             : [],
-  
+  _errors           : [],
+
   onPageShow: function ()
   {
     gUpdateWizard.setButtonLabels(null, true, 
@@ -375,19 +386,16 @@ var gInstallingPage = {
     var items = [];
     var hashes = [];
     this._objs = [];
-    
-    this._restartRequired = false;
-    
-    gUpdateWizard.remainingExtensionUpdateCount = gUpdateWizard.itemsToUpdate.length;
+    this._errors = [];
 
-    var updates = document.getElementById("found.updates");
-    var checkboxes = updates.selectedItem.getElementsByTagName("checkbox");
-    for (var i = 0; i < checkboxes.length; ++i) {
-      if (checkboxes[i].type == "update" && checkboxes[i].checked) {
-        items.push(checkboxes[i].URL);
-        hashes.push(checkboxes[i].hash ? checkboxes[i].hash : null);
-        this._objs.push({ name: checkboxes[i].label });
-      }
+    var foundUpdates = document.getElementById("found.updates");
+    var updates = foundUpdates.getElementsByTagName("listitem");;
+    for (var i = 0; i < updates.length; ++i) {
+      if (!updates[i].checked)
+        continue;
+      items.push(updates[i].value);
+      hashes.push(updates[i].getAttribute("hash") ? updates[i].getAttribute("hash") : null);
+      this._objs.push({ name: updates[i].label });
     }
     
     var xpimgr = Components.classes["@mozilla.org/xpinstall/install-manager;1"]
@@ -417,26 +425,22 @@ var gInstallingPage = {
       break;
     case nsIXPIProgressDialog.INSTALL_DONE:
       switch (aValue) {
-      case 999: 
-        this._restartRequired = true;
-        break;
-      case 0: 
-        --gUpdateWizard.remainingExtensionUpdateCount;
+      case 999:
+      case 0:
         break;
+      default:
+        this._errors.push({ name: this._objs[aIndex].name, error: aValue });
       }
       break;
     case nsIXPIProgressDialog.DIALOG_CLOSE:
       this._installing = false;
-      var nextPage = this._errors ? "errors" : (this._restartRequired ? "restart" : "finished");
+      var nextPage = this._errors.length > 0 ? "installerrors" : "finished";
       document.getElementById("installing").setAttribute("next", nextPage);
       document.documentElement.advance();
       break;
     }
   },
   
-  _objs: [],
-  _errors: false,
-  
   onProgress: function (aIndex, aValue, aMaxValue)
   {
     var downloadProgress = document.getElementById("downloadProgress");
@@ -444,67 +448,64 @@ var gInstallingPage = {
   }
 };
 
-var gErrorsPage = {
+var gInstallErrorsPage = {
   onPageShow: function ()
   {
+    gUpdateWizard.setButtonLabels(null, true, null, true, null, true);
     document.documentElement.getButton("finish").focus();
-    gUpdateWizard.succeeded = false;
   },
   
   onShowErrors: function ()
   {
-    gUpdateWizard.showErrors("install", gInstallingPage._objs);
-  }  
+    gUpdateWizard.showErrors("install", gInstallingPage._errors);
+  }
 };
 
+// Displayed when there are incompatible add-ons and the xpinstall.enabled
+// pref is false and locked.
+var gAdminDisabledPage = {
+  onPageShow: function ()
+  {
+    gUpdateWizard.setButtonLabels(null, true, null, true, 
+                                  "cancelButtonText", true);
+    document.documentElement.getButton("finish").focus();
+  }
+};
+
+// Displayed when selected add-on updates have been installed without error.
+// There can still be add-ons that are not compatible and don't have an update.
 var gFinishedPage = {
   onPageShow: function ()
   {
     gUpdateWizard.setButtonLabels(null, true, null, true, null, true);
     document.documentElement.getButton("finish").focus();
     
-    var iR = document.getElementById("incompatibleRemaining");
-    var iR2 = document.getElementById("incompatibleRemaining2");
-    var fEC = document.getElementById("finishedEnableChecking");
-
     if (gUpdateWizard.shouldSuggestAutoChecking) {
-      iR.hidden = true;
-      iR2.hidden = false;
-      fEC.hidden = false;
-      fEC.click();
-    }
-    else {
-      iR.hidden = false;
-      iR2.hidden = true;
-      fEC.hidden = true;
-    }
-    
-    if (gShowMismatch) {
-      document.getElementById("finishedMismatch").hidden = false;
-      document.getElementById("incompatibleAlert").hidden = false;
+      document.getElementById("finishedCheckDisabled").hidden = false;
+      gUpdateWizard.shouldAutoCheck = true;
     }
+    else
+      document.getElementById("finishedCheckEnabled").hidden = false;
+
+    document.documentElement.getButton("finish").focus();
   }
 };
 
+// Displayed when there are incompatible add-ons and there are no available
+// updates.
 var gNoUpdatesPage = {
   onPageShow: function (aEvent)
   {
     gUpdateWizard.setButtonLabels(null, true, null, true, null, true);
-    document.documentElement.getButton("finish").focus();
-    if (gShowMismatch) {
-      document.getElementById("introUser").hidden = true;
-      document.getElementById("introMismatch").hidden = false;
-      document.getElementById("mismatchNoUpdates").hidden = false;
-        
-      if (gUpdateWizard.shouldSuggestAutoChecking) {
-        document.getElementById("mismatchIncompatibleRemaining").hidden = true;
-        document.getElementById("mismatchIncompatibleRemaining2").hidden = false;
-        document.getElementById("mismatchFinishedEnableChecking").hidden = false;
-      }
+    if (gUpdateWizard.shouldSuggestAutoChecking) {
+      document.getElementById("noupdatesCheckDisabled").hidden = false;
+      gUpdateWizard.shouldAutoCheck = true;
     }
+    else
+      document.getElementById("noupdatesCheckEnabled").hidden = false;
 
-    gUpdateWizard.succeeded = false;
     gUpdateWizard.checkForErrors("updateCheckErrorNotFound");
+    document.documentElement.getButton("finish").focus();
   }
 };
 
